# ------------------------------------------------------------------------------ 
# This CMake code installs the needed support libraries on NON OSX platforms.
# For OS X platforms build and install MXADataModel using the RPATH. Then when
# you build your final executable you should be able to adjust the install_name
# of the MXADataModel library using "install_name_tool" to be what you need.
# ------------------------------------------------------------------------------

#------- Macro to find and install the proper dynamic libraries ----------------
MACRO (MXA_INSTALL_SUPPORT_LIBRARY basename)
    IF (HAVE_${basename}_DLL)
      IF (WIN32 AND HAVE_${basename}_DLL STREQUAL "1")
        GET_FILENAME_COMPONENT(${basename}_LIB_DEBUG_NAME ${${basename}_LIBRARY_DEBUG} NAME_WE)
        GET_FILENAME_COMPONENT(${basename}_LIB_RELEASE_NAME ${${basename}_LIBRARY_RELEASE} NAME_WE)

        INSTALL(FILES ${${basename}_BIN_DIR}/${${basename}_LIB_DEBUG_NAME}.dll 
            DESTINATION bin 
            CONFIGURATIONS Debug 
            COMPONENT Runtime)
        INSTALL(FILES ${${basename}_BIN_DIR}/${${basename}_LIB_RELEASE_NAME}.dll 
            DESTINATION bin 
            CONFIGURATIONS Release 
            COMPONENT Runtime)
      ENDIF (WIN32 AND HAVE_${basename}_DLL STREQUAL "1")
    ENDIF (HAVE_${basename}_DLL)
ENDMACRO(MXA_INSTALL_SUPPORT_LIBRARY basename)

#-- Install the support libraries if needed
IF ( "ON" STREQUAL "ON")
set(HAVE_HDF5_DLL 1)
MXA_INSTALL_SUPPORT_LIBRARY(HDF5)
ENDIF()

IF ("ON" STREQUAL "ON")
set(HAVE_EXPAT_DLL 1)
MXA_INSTALL_SUPPORT_LIBRARY(EXPAT)
ENDIF()

IF("ON" STREQUAL "ON")
set(HAVE_TIFF_DLL 1)
MXA_INSTALL_SUPPORT_LIBRARY(TIFF)
ENDIF()

#-- Anything that depends on MXADataModel will need to have it installed
set(HAVE_MXADATAMODEL_DLL 1)
MXA_INSTALL_SUPPORT_LIBRARY(MXADATAMODEL)

# -------------------------- Find the MinGW Runtime library --------------------
IF (MINGW)
    INCLUDE ( ${MXA_CMAKE_DIR}/MXAFindMinGW.cmake )
    IF (MINGW_FOUND)
        INSTALL(FILES ${MINGW_LIBRARIES}
                DESTINATION bin
                COMPONENT Runtime)
    ENDIF (MINGW_FOUND)
ENDIF (MINGW)
